@@ -19,7 +19,7 @@ from prettytable import PrettyTable, DOUBLE_BORDER
 class PrinterPrettyTable(PrinterTableGateway):
     def _create_table(self, headers, finding_list):
         table = PrettyTable(headers)
-
+        
         for finding in finding_list:
             row_data = [
                 finding.severity,
@@ -31,7 +31,9 @@ class PrinterPrettyTable(PrinterTableGateway):
                 finding.module == "engine_dependencies"
             ):
                 row_data.append(finding.requirements)
-
+            elif finding.module == "engine_code":
+                row_data.append(finding.cvss)
+                row_data.append(finding.defect_type)
             table.add_row(row_data)
 
         severity_order = {"critical": 0, "high": 1, "medium": 2, "low": 3, "unknown": 4}
@@ -50,12 +52,17 @@ class PrinterPrettyTable(PrinterTableGateway):
     def print_table_findings(self, finding_list: "list[Finding]"):
         if (
             finding_list
-            and (finding_list[0].module != "engine_container")
-            and (finding_list[0].module != "engine_dependencies")
+            and (
+                (finding_list[0].module == "engine_container") 
+                or (finding_list[0].module == "engine_dependencies")
+                )
         ):
-            headers = ["Severity", "ID", "Description", "Where"]
-        else:
             headers = ["Severity", "ID", "Description", "Where", "Fixed in"]
+        elif finding_list and finding_list[0].module == "engine_code":
+            headers = ["Severity", "ID", "Description", "Where", "Rule", "Defect Type"]
+
+        else:
+            headers = ["Severity", "ID", "Description", "Where"]
 
         sorted_table = self._create_table(headers, finding_list)
 
@@ -165,4 +172,4 @@ class PrinterPrettyTable(PrinterTableGateway):
             new_value = "\n".join(values)
         else:
             new_value = f"{values[0]}"
-        return new_value
+        return new_value
\ No newline at end of file
